@@ -38,9 +38,6 @@ class FlareAnalysisConfig(BaseConfig):
     smoothing_window_size: int = 20
     smoothing_cooldown_frames: int = 5
     smoothing_confidence_range_factor: float = 0.5
-    intensity_thresholds: Dict[str, float] = field(default_factory=lambda: {
-        "red": 0.8, "yellow": 0.6, "orange": 0.7, "blue": 0.9, "white": 0.95
-    })
 
     def validate(self) -> List[str]:
         errors = super().validate()
@@ -164,7 +161,6 @@ class FlareAnalysisUseCase(BaseProcessor):
         }
 
     def get_config_schema(self) -> Dict[str, Any]:
-        """Get JSON schema for configuration validation."""
         return {
             "type": "object",
             "properties": {
@@ -175,15 +171,13 @@ class FlareAnalysisUseCase(BaseProcessor):
                 "fps": {"type": ["number", "null"], "minimum": 1.0, "default": None},
                 "bbox_format": {"type": "string", "enum": ["auto", "xmin_ymin_xmax_ymax", "x_y_width_height"], "default": "auto"},
                 "index_to_category": {"type": ["object", "null"], "default": {0: 'BadFlare', 1: 'GoodFlare'}},
-                "alert_config": {"type": ["object", "null"], "default": None},
-                "intensity_thresholds": {"type": "object", "default": {"red": 0.8, "yellow": 0.6, "orange": 0.7, "blue": 0.9, "white": 0.95}}
+                "alert_config": {"type": ["object", "null"], "default": None}
             },
             "required": ["confidence_threshold", "top_k_colors"],
             "additionalProperties": False
         }
 
     def create_default_config(self, **overrides) -> FlareAnalysisConfig:
-        """Create default configuration with optional overrides."""
         defaults = {
             "category": self.category,
             "usecase": self.name,
@@ -194,8 +188,7 @@ class FlareAnalysisUseCase(BaseProcessor):
             "fps": None,
             "bbox_format": "auto",
             "index_to_category": {0: 'BadFlare', 1: 'GoodFlare'},
-            "alert_config": None,
-            "intensity_thresholds": {"red": 0.8, "yellow": 0.6, "orange": 0.7, "blue": 0.9, "white": 0.95}
+            "alert_config": None
         }
         defaults.update(overrides)
         return FlareAnalysisConfig(**defaults)
@@ -268,7 +261,6 @@ class FlareAnalysisUseCase(BaseProcessor):
             except Exception as e:
                 self.logger.warning(f"AdvancedTracker failed: {e}")
 
-            # flare_processed_data = self._deduplicate_detections(flare_processed_data, iou_thresh=0.7)
             self._update_flare_tracking_state(flare_processed_data)
             self._total_frame_counter += 1
 
@@ -381,7 +373,6 @@ class FlareAnalysisUseCase(BaseProcessor):
                         continue
                     major_colors = extract_major_colors(crop, k=config.top_k_colors)
                     main_color = major_colors[0][0] if major_colors else "unknown"
-                    intensity = self._calculate_flare_intensity(main_color, major_colors[0][2], config)
                     flare_record = {
                         "frame_id": frame_key,
                         "timestamp": round(timestamp, 2),
@@ -389,7 +380,6 @@ class FlareAnalysisUseCase(BaseProcessor):
                         "confidence": round(detection.get("confidence", 0.0), 3),
                         "main_color": main_color,
                         "major_colors": major_colors,
-                        "intensity": intensity,
                         "bbox": bbox,
                         "detection_id": detection.get("id", f"det_{len(flare_analysis)}"),
                         "track_id": detection.get("track_id")
@@ -421,7 +411,6 @@ class FlareAnalysisUseCase(BaseProcessor):
                 continue
             major_colors = extract_major_colors(crop, k=config.top_k_colors)
             main_color = major_colors[0][0] if major_colors else "unknown"
-            intensity = self._calculate_flare_intensity(main_color, major_colors[0][2], config)
             flare_record = {
                 "frame_id": "0",
                 "timestamp": 0.0,
@@ -429,7 +418,6 @@ class FlareAnalysisUseCase(BaseProcessor):
                 "confidence": round(detection.get("confidence", 0.0), 3),
                 "main_color": main_color,
                 "major_colors": major_colors,
-                "intensity": intensity,
                 "bbox": bbox,
                 "detection_id": detection.get("id", f"det_{len(flare_analysis)}"),
                 "track_id": detection.get("track_id")
@@ -462,37 +450,35 @@ class FlareAnalysisUseCase(BaseProcessor):
             return np.zeros((0, 0, 3), dtype=np.uint8)
         return image[ymin:ymax, xmin:xmax]
 
-    def _calculate_flare_intensity(self, main_color: str, confidence: float, config: FlareAnalysisConfig) -> float:
-        threshold = config.intensity_thresholds.get(main_color, 0.5)
-        return round(confidence * (1.0 if confidence >= self.threshold else 0.5), 2)
-
     def _calculate_flare_summary(self, flare_analysis: List[Dict], config: FlareAnalysisConfig) -> Dict[str, Any]:
         category_colors = defaultdict(lambda: defaultdict(int))
-        intensity_counts = defaultdict(int)
         total_detections = len(flare_analysis)
         detections = []
         for record in flare_analysis:
             category = record["category"]
             main_color = record["main_color"]
-            intensity = record["intensity"]
             category_colors[category][main_color] += 1
-            intensity_counts[main_color] += 1
             detections.append({
                 "bounding_box": record["bbox"],
-                "category": category,
+                "category": record["category"],
                 "confidence": record["confidence"],
                 "track_id": record["track_id"],
                 "frame_id": record["frame_id"],
-                "main_color": main_color,
-                "intensity": intensity
+                "main_color": record["main_color"]
             })
         summary = {
             "total_detections": total_detections,
             "categories": dict(category_colors),
-            "color_distribution": dict(intensity_counts),
+            "color_distribution": {},
             "dominant_colors": {},
-            "detections": detections
+            "detections": detections,
+            "total_flare_counts": self.get_total_flare_counts()
         }
+        all_colors = defaultdict(int)
+        for category_data in category_colors.values():
+            for color, count in category_data.items():
+                all_colors[color] += count
+        summary["color_distribution"] = dict(all_colors)
         for category, colors in category_colors.items():
             if colors:
                 dominant_color = max(colors.items(), key=lambda x: x[1])
@@ -571,7 +557,7 @@ class FlareAnalysisUseCase(BaseProcessor):
                         "threshold": threshold,
                         "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
                     })
-                elif category in flare_summary.get("categories", {}) and category == "BadFlare":
+                elif category in flare_summary.get("categories", {}):
                     category_total = sum(flare_summary["categories"][category].values())
                     if category_total >= threshold:
                         alerts.append({
@@ -583,21 +569,6 @@ class FlareAnalysisUseCase(BaseProcessor):
                             "threshold": threshold,
                             "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
                         })
-                for record in flare_summary.get("detections", []):
-                    if record["category"] != "BadFlare":
-                        continue
-                    color = record["main_color"]
-                    intensity = record["intensity"]
-                    if color in config.intensity_thresholds and intensity >= config.intensity_thresholds[color]:
-                        alerts.append({
-                            "type": "intensity_threshold",
-                            "severity": "critical",
-                            "message": f"{color} {record['category']} detected with intensity {intensity}",
-                            "category": record["category"],
-                            "current_intensity": intensity,
-                            "threshold": config.intensity_thresholds[color],
-                            "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')
-                        })
         return alerts
 
     def _calculate_metrics(self, flare_analysis: List[Dict], flare_summary: Dict, config: FlareAnalysisConfig, context: ProcessingContext) -> Dict[str, Any]:
@@ -612,7 +583,15 @@ class FlareAnalysisUseCase(BaseProcessor):
             "confidence_threshold": config.confidence_threshold,
             "color_diversity": (unique_colors / total_detections) * 100 if total_detections > 0 else 0.0,
             "detection_rate": (total_detections / config.time_window_minutes) * 60 if config.time_window_minutes > 0 else 0.0,
-            "average_colors_per_detection": config.top_k_colors
+            "average_colors_per_detection": config.top_k_colors,
+            "category_metrics": {},
+            "processing_settings": {
+                "confidence_threshold": config.confidence_threshold,
+                "top_k_colors": config.top_k_colors,
+                "frame_skip": config.frame_skip,
+                "target_categories": config.target_categories,
+                "enable_unique_counting": config.enable_unique_counting
+            }
         }
         category_metrics = {}
         for category, colors in flare_summary.get("categories", {}).items():
@@ -623,13 +602,6 @@ class FlareAnalysisUseCase(BaseProcessor):
                 "color_diversity": (len(colors) / category_total) * 100 if category_total > 0 else 0
             }
         metrics["category_metrics"] = category_metrics
-        metrics["processing_settings"] = {
-            "confidence_threshold": config.confidence_threshold,
-            "top_k_colors": config.top_k_colors,
-            "frame_skip": config.frame_skip,
-            "target_categories": config.target_categories,
-            "enable_unique_counting": config.enable_unique_counting
-        }
         return metrics
 
     def _extract_predictions(self, flare_analysis: List[Dict], config: FlareAnalysisConfig) -> List[Dict]:
@@ -642,8 +614,7 @@ class FlareAnalysisUseCase(BaseProcessor):
                 "frame_id": record["frame_id"],
                 "timestamp": record["timestamp"],
                 "main_color": record["main_color"],
-                "major_colors": record["major_colors"],
-                "intensity": record["intensity"]
+                "major_colors": record["major_colors"]
             }
             if "detection_id" in record:
                 prediction["id"] = record["detection_id"]
@@ -698,11 +669,9 @@ class FlareAnalysisUseCase(BaseProcessor):
                 "application_version": "1.0",
                 "location_info": None,
                 "human_text": (
-                    f"Event: Flare Detection\nLevel: {level.title()}\n"
-                    f"Time: {datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC')}\n"
                     f"Detections: {total_detections} flares analyzed\n"
                     f"Unique Colors: {len(flare_summary.get('color_distribution', {}))}\n"
-                    f"Intensity: {intensity:.1f}/10"
+                    
                 )
             }
             frame_events.append(event)
@@ -720,7 +689,7 @@ class FlareAnalysisUseCase(BaseProcessor):
                 "application_name": "Flare Analysis Alert System",
                 "application_version": "1.0",
                 "location_info": alert.get("category"),
-                "human_text": f"Event: {alert.get('type', 'Flare Alert').title()}\nMessage: {alert.get('message', 'Flare detection alert triggered')}"
+                "human_text": f"{alert.get('type', 'Flare Alert').title()}\n{alert.get('message', 'Flare detection alert triggered')}"
             }
             frame_events.append(alert_event)
         return events
