@@ -274,7 +274,7 @@ class VehicleMonitoringUseCase(BaseProcessor):
             self.logger.warning(f"AdvancedTracker failed: {e}")
 
         # Deduplicate overlapping vehicles (same label, high IoU)
-        # processed_data = self._deduplicate_vehicles(processed_data, iou_thresh=0.92)
+        processed_data = self._deduplicate_vehicles(processed_data, iou_thresh=0.95)
 
         # Update vehicle tracking state for total count per label
         self._update_vehicle_tracking_state(processed_data)
@@ -745,4 +745,3 @@ class VehicleMonitoringUseCase(BaseProcessor):
         }
         return canonical_id
 
-
